@@ -5,7 +5,10 @@ The FirstWindow: upload_magnetogram.py
 To start the Main UI:
 
 from mesh_generator.ui.upload_magnetogram import MeshGeneratorUI
->>> MeshGeneratorUI()
+
+MeshGeneratorUI() # then call the UI first window.
 """
 
 from mesh_generator.ui.upload_magnetogram import MeshGeneratorUI
+from mesh_generator.ui.tkinter_mainapp import MeshApp
+from mesh_generator.ui.auto_mesh_from_dict import MeshRes
\ No newline at end of file
