@@ -100,7 +100,7 @@ class MeshApp:
             .grid(row=7, column=0, columnspan=7, sticky=tk.W, pady=10)
         tk.Label(self.leftFrame, text="ds", relief=tk.RIDGE, bg='lightgray', bd=2). \
             grid(row=8, column=1, sticky=tk.NSEW)
-        tk.Label(self.leftFrame, text="var_ds_ratio", relief=tk.RIDGE, bg='lightgray', bd=2). \
+        tk.Label(self.leftFrame, text="ratio", relief=tk.RIDGE, bg='lightgray', bd=2). \
             grid(row=8, column=2, sticky=tk.NSEW, columnspan=2)
 
         # second frame: includes step 3, 4 and building a radial mesh manually.
@@ -190,7 +190,7 @@ class MeshApp:
         tk.Label(self.rightFrame, text='ds', relief=tk.RIDGE, bg='lightgray', bd=2, width=6).grid(row=10, column=3,
                                                                                                   sticky=tk.NSEW,
                                                                                                   columnspan=1)
-        tk.Label(self.rightFrame, text='var_ds_ratio', relief=tk.RIDGE, bg='lightgray', bd=2, width=9).grid(row=10,
+        tk.Label(self.rightFrame, text='ratio', relief=tk.RIDGE, bg='lightgray', bd=2, width=9).grid(row=10,
                                                                                                             column=4,
                                                                                                             sticky=tk.NSEW,
                                                                                                             columnspan=1)
@@ -443,10 +443,11 @@ class MeshApp:
             np_p = self.num_points_phi()
             np_r = self.num_points_r()
             total_np = int(np_t) * int(np_p) * int(np_r)
+            tk.Label(self.rightFrame, text=str('{:.2e}'.format(total_np))).grid(row=6, column=3, sticky=tk.W,
+                                                                                columnspan=2)
         except:
             total_np = "n/a"
-        tk.Label(self.rightFrame, text=str('{:.2e}'.format(total_np))).grid(row=6, column=3, sticky=tk.W,
-                                                                                    columnspan=2)
+            tk.Label(self.rightFrame, text=total_np).grid(row=6, column=3, sticky=tk.W, columnspan=2)
 
     def write_tmp_mas_files(self):
         """write a tmp mas files"""
